==> gspiceui_0.9.98.dfsg.orig.tar.gz: gspiceui-0.9.98.dfsg/src/AppGSpiceUI.cpp <==
//*****************************************************************************
//                               AppGSpiceUI.cpp                              *
//                              -----------------                             *
//  Started     : 15/08/2003                                                  *
//  Last Update : 22/10/2008                                                  *
//  Copyright   : (C) 2003 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "AppGSpiceUI.hpp"

//*****************************************************************************
// All programs must have a "main" function. Under wxWidgets main( ) is
// implemented using the following macro which creates an application instance
// and starts program execution.

IMPLEMENT_APP( AppGSpiceUI )

//*****************************************************************************
// Implement an event table in which the events are routed to their respective
// handler functions in the class. If -1 is given as the ID, the given handler
// will be invoked for any event of the specified type.

//BEGIN_EVENT_TABLE( AppGSpiceUI, wxApp )


//END_EVENT_TABLE( )

//*****************************************************************************
// Constructor.

AppGSpiceUI::AppGSpiceUI( void )
{
  m_poFrmMain = NULL;

  // The following line magically makes locale stuff work, don't touch!
  setlocale( LC_NUMERIC, "C" );
}

//*****************************************************************************
// Destructor.

AppGSpiceUI::~AppGSpiceUI( )
{
}

//*****************************************************************************
// wxWindows calls wxApp::OnInit( ) at startup, the method is used to
// initialize the application.
//
// Return Values:
//   TRUE  - Success (continue  application execution)
//   FALSE - Failure (terminate application execution)

bool  AppGSpiceUI::OnInit( void )
{
  // Set the command line and process it
  if( ! m_oCmdLnPcr.bSetCmdLine( argc, argv ) ) return( FALSE );
  if( ! m_oCmdLnPcr.bProcArgs( ) )              return( FALSE );

  // Create the GUI
  m_poFrmMain = new FrmMain( this );
  m_poFrmMain->Show( TRUE );
  SetTopWindow( m_poFrmMain );

  return( TRUE );
}

//*****************************************************************************
// wxWindows calls wxApp::Mainloop( ) on creation of the application.
//
// Return Values:
//   0 - Not used

/* int  AppGSpiceUI::MainLoop( void )
{
  while( m_poFrmMain->bIsOpen( ) )
  {
     Yield( );            // Allow messages in the event queue to be processed
     wxMilliSleep( 100 ); // Sleep for 100msec
  }

  return( 0 );
} // */

//*****************************************************************************
// wxWindows calls wxApp::OnExit( ) on application termination.
//
// Return Values:
//   0 - Not used

int  AppGSpiceUI::OnExit( void )
{
  // Delete the global configuration object
  delete wxConfig::Set( (wxConfig *) NULL );

  return( 0 );
}

//*****************************************************************************

==> gspiceui_0.9.99+dfsg.orig.tar.gz: gspiceui-0.9.99+dfsg/src/AppGSpiceUI.cpp <==
//*****************************************************************************
//                               AppGSpiceUI.cpp                              *
//                              -----------------                             *
//  Started     : 15/08/2003                                                  *
//  Last Update : 05/02/2010                                                  *
//  Copyright   : (C) 2003 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "AppGSpiceUI.hpp"

//*****************************************************************************
// All programs must have a "main" function. Under wxWidgets main( ) is
// implemented using the following macro which creates an application instance
// and starts program execution.

IMPLEMENT_APP( App_gSpiceUI )

//*****************************************************************************
// Implement an event table in which the events are routed to their respective
// handler functions in the class. If -1 is given as the ID, the given handler
// will be invoked for any event of the specified type.

//BEGIN_EVENT_TABLE( App_gSpiceUI, wxApp )


//END_EVENT_TABLE( )

//*****************************************************************************
// Constructor.

App_gSpiceUI::App_gSpiceUI( void )
{
  m_poFrmMain = NULL;
}

//*****************************************************************************
// Destructor.

App_gSpiceUI::~App_gSpiceUI( )
{
}

//*****************************************************************************
// wxWindows calls wxApp::OnInit( ) at startup, the method is used to
// initialize the application.
//
// Return Values:
//   TRUE  - Success (continue  application execution)
//   FALSE - Failure (terminate application execution)

bool  App_gSpiceUI::OnInit( void )
{
  // The following line magically makes locale stuff work, don't touch!
  setlocale( LC_NUMERIC, "C" );

  // Set the command line and process it
  if( ! m_oCmdLnPcr.bSetCmdLine( argc, argv ) ) return( FALSE );
  if( ! m_oCmdLnPcr.bProcArgs( ) )              return( FALSE );

  // Create the GUI
  m_poFrmMain = new FrmMain( this );
  m_poFrmMain->Show( TRUE );
  SetTopWindow( m_poFrmMain );

  return( TRUE );
}

//*****************************************************************************
// wxWindows calls wxApp::Mainloop( ) on creation of the application.
//
// Return Values:
//   0 - Not used

/* int  App_gSpiceUI::MainLoop( void )
{
  while( m_poFrmMain->bIsOpen( ) )
  {
     Yield( );            // Allow messages in the event queue to be processed
     wxMilliSleep( 100 ); // Sleep for 100msec
  }

  return( 0 );
} // */

//*****************************************************************************
// wxWindows calls wxApp::OnExit( ) on application termination.
//
// Return Values:
//   0 - Not used

int  App_gSpiceUI::OnExit( void )
{
  // Delete the global configuration object
  delete wxConfig::Set( (wxConfig *) NULL );

  return( 0 );
}

//*****************************************************************************
